<?php

declare(strict_types=1);
namespace Drupal\translation_bliss_fixed_admin_language\Plugin\LanguageNegotiation;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\language\Attribute\LanguageNegotiation;
use Drupal\user\Plugin\LanguageNegotiation\LanguageNegotiationUserAdmin;
use Symfony\Component\HttpFoundation\Request;

/**
 * Forces fixed language on admin pages.
 *
 * @internal
 */
#[LanguageNegotiation(
  id: TranslationBlissFixedAdminLanguageNegotiation::METHOD_ID,
  name: new TranslatableMarkup('Fixed language on administration pages'),
  types: [LanguageInterface::TYPE_INTERFACE],
  weight: -10,
  description: new TranslatableMarkup('Account administration pages language setting.'),
  config_route_name: 'translation_bliss_fixed_admin_language.form',
)]
final class TranslationBlissFixedAdminLanguageNegotiation extends LanguageNegotiationUserAdmin {

  const METHOD_ID = 'translation-bliss-fixed-admin-language';

  public function getLangcode(Request $request = NULL) {
    $langcode = NULL;
    $isAdminPath = $this->isAdminPath($request);
    if ($isAdminPath) {
      $langcode = $this->config->get('translation_bliss_fixed_admin_language.settings')->get('selected_langcode');
    }
    return $langcode;
  }

}
