<?php

declare(strict_types=1);
namespace Drupal\Tests\translation_bliss\Functional;

use Drupal\Core\File\FileSystemInterface;
use Drupal\language\Entity\ConfigurableLanguage;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\translation_bliss\Traits\FixDriverTrait;
use Drupal\translation_bliss\Drush\Commands\PotxCommands\Utility\TranslationStatusFilter;
use Drush\TestTraits\DrushTestTrait;

final class PotxBlissTest extends BrowserTestBase {

  use FixDriverTrait;
  use DrushTestTrait;

  protected static $modules = [
    'translation_bliss',
    'potx',
    'language'
  ];

  protected $defaultTheme = 'stark';

  public function testPotxBliss(): void {
    ConfigurableLanguage::createFromLangcode('de')
      ->save();

    $fs = \Drupal::service(FileSystemInterface::class);
    assert($fs instanceof FileSystemInterface);
    $targetDir = $fs->getTempDirectory() . "/" . $this->randomMachineName();

    $sourceDir = \Drupal::moduleHandler()
      ->getModule('translation_bliss')
      ->getPath() . '/tests/modules/translation_bliss_test';

    $this->drush('potxx', options: ['source' => $sourceDir, 'target' => $targetDir]);

    // @todo Also verify all translation strings got dumped.
    $expectedFiles = [
      "$targetDir/all.pot",
      "$targetDir/custom.de.po",
      "$targetDir/shipped.de._po",
    ];
    $this->assertEquals($expectedFiles, glob("$targetDir/*"));

    // Also verify that source annotations are only in .pot.
    $this->assertStringContainsString('#:', file_get_contents("$targetDir/all.pot"));
    $this->assertStringNotContainsString('#:', file_get_contents("$targetDir/custom.de.po"));

    $fs->deleteRecursive($targetDir);
  }

}
